@@ -41,7 +41,7 @@ predictions <- function(x, ...)  UseMethod("predictions")
 ##' @aliases predictions
 ##' @export
 predictions.ranger.prediction <- function(x, ...) {
-  if (class(x) != "ranger.prediction") {
+  if (!inherits(x, "ranger.prediction")) {
     stop("Object ist no ranger.prediction object.")
   }
   if (x$treetype == "Classification" || x$treetype == "Regression" || x$treetype == "Probability estimation") {
@@ -71,8 +71,8 @@ predictions.ranger.prediction <- function(x, ...) {
 ##' @seealso \code{\link{ranger}}
 ##' @author Marvin N. Wright
 ##' @export
-predictions.ranger<- function(x, ...) {
-  if (class(x) != "ranger") {
+predictions.ranger <- function(x, ...) {
+  if (!inherits(x, "ranger")) {
     stop("Object ist no ranger object.")
   }
   if (x$treetype == "Classification" || x$treetype == "Regression" || x$treetype == "Probability estimation") {
@@ -91,3 +91,21 @@ predictions.ranger<- function(x, ...) {
     stop("Unknown tree type.")
   }
 }
+
+##' @export
+as.data.frame.ranger.prediction <- function(x, ...) {
+  if (x$treetype == "Survival") {
+    df <- data.frame(x$survival)
+    colnames(df) <- paste0("time=", x$unique.death.times)
+  } else if (x$treetype == "Probability estimation") {
+    df <- data.frame(x$predictions)
+  } else {
+    df <- data.frame(prediction = x$predictions)
+  }
+  
+  if (!is.null(x$se)) {
+    df$se <- x$se
+  }
+  
+  df
+} 
